==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sq.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Emër libri adresash",
    "No contacts in here" : "S’ka kontakte këtu",
    "Name" : "Emër",
    "Organization" : "Organizëm",
    "Title" : "Titull",
    "Add field ..." : "Shtoni fushë...",
    "Import" : "Importoje",
    "Add contact" : "Shtoni kontakt",
    "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
    "All contacts" : "Krejt kontaktet",
    "Not grouped" : "I pagrupuar",
    "Post Office Box" : "Kuti Zyre Postare",
    "Postal Code" : "Kod Postar",
    "City" : "Qytet",
    "State or province" : "Shtet ose provincë",
    "Country" : "Vend",
    "Address" : "Adresë",
    "(new group)" : "(grup i ri)",
    "New contact" : "Kontakt i ri",
    "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
    "Invalid file type." : "Lloj i pavlefshëm kartele.",
    "Nickname" : "Nofkë",
    "Notes" : "Shënime",
    "Website" : "Sajt",
    "Federated Cloud ID" : "ID Federated Cloud",
    "Home" : "Kreu",
    "Work" : "Pune",
    "Other" : "Tjetër",
    "Groups" : "Grupe",
    "Birthday" : "Datëlindje",
    "Email" : "Email",
    "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
    "Phone" : "Telefon",
    "Mobile" : "Celular",
    "Fax" : "Faks",
    "Fax home" : "Faks shtëpie",
    "Fax work" : "Faks pune",
    "Pager" : "Faques",
    "Voice" : "Zë",
    "Social Network" : "Rrjet Shoqëror",
    "Settings" : "Rregullime"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.3.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sq.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Emër libri adresash",
    "No contacts in here" : "S’ka kontakte këtu",
    "Name" : "Emër",
    "Organization" : "Organizëm",
    "Title" : "Titull",
    "Add field ..." : "Shtoni fushë...",
    "Import" : "Importoje",
    "Add contact" : "Shtoni kontakt",
    "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
    "All contacts" : "Krejt kontaktet",
    "Not grouped" : "I pagrupuar",
    "Post Office Box" : "Kuti Zyre Postare",
    "Postal Code" : "Kod Postar",
    "City" : "Qytet",
    "State or province" : "Shtet ose provincë",
    "Country" : "Vend",
    "Address" : "Adresë",
    "(new group)" : "(grup i ri)",
    "New contact" : "Kontakt i ri",
    "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
    "No contacts in file. Only VCard files are allowed." : "S’ka kontakte në kartelë. Lejohen vetëm kartela VCard.",
    "Nickname" : "Nofkë",
    "Notes" : "Shënime",
    "Website" : "Sajt",
    "Federated Cloud ID" : "ID Federated Cloud",
    "Home" : "Kreu",
    "Work" : "Pune",
    "Other" : "Tjetër",
    "Groups" : "Grupe",
    "Birthday" : "Datëlindje",
    "Email" : "Email",
    "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
    "Phone" : "Telefon",
    "Mobile" : "Celular",
    "Fax" : "Faks",
    "Fax home" : "Faks shtëpie",
    "Fax work" : "Faks pune",
    "Pager" : "Faques",
    "Voice" : "Zë",
    "Social Network" : "Rrjet Shoqëror",
    "Settings" : "Rregullime"
},
"nplurals=2; plural=(n != 1);");
